#############################################################"
## FC13_publication_dataset-creation.R
##
## Create the FC13_data object, which contain all needed data.
#############################################################"

otus_raw <- read.csv('data/FC13_otus.csv', sep=";", h=T, row.names=1)
mapfile <- read.csv("data/FC13_mapfile.csv", sep=";", h=T, row.names=1)
blast <- read.csv("data/FC13_blast.csv", sep=";", h=T, row.names=1)

# check that the files match (each line must be TRUE)
sum(rownames(otus_raw)==rownames(mapfile))==nrow(otus_raw)
sum(colnames(otus_raw)==rownames(blast))==ncol(otus_raw)

# In the mapping file, change the order of the factor levels
str(mapfile)
mapfile$transect <- factor(mapfile$transect, levels=c("CbC", "CbE","CsC", "CsE","QC", "QE", "VE", "VC", "temoin"))
mapfile$species <- factor(mapfile$species, levels=c("Cb", "Cs", "Q", "V", "temoin"))
mapfile$date <- ordered(mapfile$date, levels=c("5", "7", "10", "temoin"))


############################################
#### Non fungal OTUs

summary(blast$kingdom)

# Keep only the "Fungi" OTUs
NCBI_fungal_otus <- rownames(blast)[blast$kingdom=="Fungi"]
sum(otus_raw) # total number of sequences
sum(otus_raw[,colnames(otus_raw)%in%NCBI_fungal_otus]) # number of fungal sequences
sum(otus_raw[,colnames(otus_raw)%in%NCBI_fungal_otus])/sum(otus_raw)*100 # percentage of fungal sequences

otus_fungi <- otus_raw[ ,colnames(otus_raw)%in%NCBI_fungal_otus]
dim(otus_fungi)


############################################
#### Control samples

otus_control <- otus_fungi[mapfile$compartment=="temoin",]
otus_control <- otus_control[,colSums(ifelse(otus_control>0,1,0))!=0]
ncol(otus_control) #Number of OTUs in the controls
sum(otus_control) #Number of sequences in the controls

## Which OTUs are in the control samples ?
blast_control <- blast[rownames(blast)%in%colnames(otus_control),]
temp <- otus_fungi[!mapfile$compartment=="temoin",colnames(otus_fungi)%in%colnames(otus_control)]

data.frame(t(otus_control), 
			  blast_hit_species = blast_control$species, 
			  nb_seq = colSums(temp), 
			  occurence = colSums(ifelse(temp>0,1,0))
)
rm(temp)

	
## Remove the control samples
otus_fungi_wcontrol <- otus_fungi[!mapfile$compartment=="temoin" ,]
otus_fungi_wcontrol <- otus_fungi_wcontrol[,colSums(otus_fungi_wcontrol)!=0]
dim(otus_fungi_wcontrol)


############################################
#### Samples with few sequences
sort(rowSums(otus_fungi_wcontrol))[1:15]

library(lattice)
barchart(sort(rowSums(otus_fungi_wcontrol)),
			panel = function(...) { 
				panel.barchart(...)
				panel.abline(v=0, col="black")
			})

# s_196 - Remove the two smaller samples 5CO_VE3 and 5CO_VC2 (rarefaction at 420)
remove_to_s196 <- names(sort(rowSums(otus_fungi_wcontrol))[1:2])
mapfile[rownames(mapfile)%in%remove_to_s196,]

otus_s196 <- otus_fungi_wcontrol[!rownames(otus_fungi_wcontrol)%in%remove_to_s196,]
otus_s196 <- otus_s196[,colSums(otus_s196)!=0]
dim(otus_s196)


############################################
### Initiate dataset

FC13_otus <- list(
	raw = otus_raw,
	fungi = otus_fungi,
	wcontrol = otus_fungi_wcontrol,
	s196 = otus_s196
)

FC13_mapfile <- list(
	raw = mapfile,
	temoin = droplevels(mapfile[mapfile$site=="temoin",]),
	wcontrol = droplevels(mapfile[mapfile$site!="temoin",]),
	s196 = droplevels(mapfile[!mapfile$site%in%"temoin"&!rownames(mapfile)%in%remove_to_s196,])
)

############################################
### alpha and beta diversity average rarefied indices
library(vegan)

OTUS <- FC13_otus$s196
sort(rowSums(OTUS), decreasing=F)[1:10]
SEUIL <- 420
ITER <- 100

set.seed(16)
RICHNESS <- 0
SHANNON <- 0
BRAY <- 0
JAC <- 0
MEAN_ABUNDANCE <- 0

for(i in 1:ITER)
{
	RAR <- rrarefy(OTUS, sample=SEUIL)
	MEAN_ABUNDANCE <- MEAN_ABUNDANCE+(RAR/ITER)
	# Diversity indices :
	RICHNESS <- RICHNESS+rowSums(ifelse(RAR>0,1,0))/ITER
	SHANNON <- SHANNON+diversity(RAR, index="shannon")/ITER
	
	# Distance matrices :
	BRAY <- BRAY+(vegdist(RAR, method="bray")/ITER)
	JAC <- JAC+(vegdist(ifelse(RAR>0,1,0), method="jaccard")/ITER)
}

## Retrieve the beta diversity indices
FC13_dist_s196 <- list(
	bray=BRAY,
	jac=JAC
)

# add the alpha diversity indices in the mapfile
FC13_mapfile$s196$richness <- RICHNESS
FC13_mapfile$s196$shannon <- SHANNON

FC13_otus$mean_rarefy_s196 <- MEAN_ABUNDANCE

FC13_otus$mean_rarefy_s196 <- FC13_otus$mean_rarefy_s196[,colSums(FC13_otus$mean_rarefy_s196)!=0]


############################################
#### Taxonomic assignations

blast_fungi <- blast[rownames(blast)%in%colnames(FC13_otus$fungi),]
blast_fungi_wcontrol <- blast[rownames(blast)%in%colnames(FC13_otus$wcontrol),]
blast_s196 <- blast[rownames(blast)%in%colnames(FC13_otus$s196),]
blast_s196_mean_rarefy <- blast[rownames(blast)%in%colnames(FC13_otus$mean_rarefy_s196),]

nrow(blast_fungi) ; nrow(blast_fungi_wcontrol) ; nrow(blast_s196) ; nrow(blast_s196_mean_rarefy)

FC13_blast <- list(
	raw = blast,
	fungi = blast_fungi,
	wcontrol = blast_fungi_wcontrol,
	s196 = blast_s196,
	s196_mean_rarefy = blast_s196_mean_rarefy
)


############################################
#### Save files
FC13_data <- list(
	otus = FC13_otus,
	mapfile = FC13_mapfile,
	blast = FC13_blast,
	dist = FC13_dist_s196)
save(FC13_data, file="data/FC13_data")
